==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ScatterPolygonSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolygonSeriesDescription } from "./ScatterPolygonSeriesDescription";
/**
 * @hidden
 */
export let ScatterPolygonSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterPolygonSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterPolygonSeriesDescriptionMetadata.a == null) {
                ScatterPolygonSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterPolygonSeriesDescriptionMetadata.c(ScatterPolygonSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterPolygonSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(ScatterPolygonSeriesDescriptionMetadata.a);
            StyleDescriptionMetadata.d(a);
        }
        static c(a) {
            ShapeSeriesBaseDescriptionMetadata.c(a);
            a.item("ShapeStyle", "ExportedType:Style");
            a.item("MarkerType", "ExportedType:string:MarkerType");
            a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
            a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
            a.item("MarkerThickness", "Number:double");
            a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
            a.item("MarkerBrush", "Brush");
            a.item("ActualMarkerBrush", "Brush");
            a.item("MarkerOutline", "Brush");
            a.item("ActualMarkerOutline", "Brush");
            a.item("MarkerCollisionAvoidance", "ExportedType:string:CollisionAvoidanceType");
            a.item("MarkerCollisionAvoidance@names", "None;Omit;Fade;OmitAndShift;FadeAndShift");
            a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
            a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
            a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
            a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
        }
        static d(a) {
            ScatterPolygonSeriesDescriptionMetadata.b(a);
            a.ad("ScatterPolygonSeries", () => new ScatterPolygonSeriesDescription());
            a.ac("ScatterPolygonSeries", ScatterPolygonSeriesDescriptionMetadata.a);
        }
    }
    ScatterPolygonSeriesDescriptionMetadata.$t = markType(ScatterPolygonSeriesDescriptionMetadata, 'ScatterPolygonSeriesDescriptionMetadata');
    ScatterPolygonSeriesDescriptionMetadata.a = null;
    return ScatterPolygonSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ScatterPolygonSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescriptionMetadata } from "./StyleDescriptionMetadata";
import { ShapeSeriesBaseDescriptionMetadata } from "./ShapeSeriesBaseDescriptionMetadata";
import { ScatterPolygonSeriesDescription } from "./ScatterPolygonSeriesDescription";
/**
 * @hidden
 */
export let ScatterPolygonSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class ScatterPolygonSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (ScatterPolygonSeriesDescriptionMetadata.a == null) {
                ScatterPolygonSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ScatterPolygonSeriesDescriptionMetadata.c(ScatterPolygonSeriesDescriptionMetadata.a);
            }
            if (a.k(ScatterPolygonSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(ScatterPolygonSeriesDescriptionMetadata.a);
            StyleDescriptionMetadata.d(a);
        }
        static c(a) {
            ShapeSeriesBaseDescriptionMetadata.c(a);
            a.item("ShapeStyle", "ExportedType:Style");
            a.item("MarkerType", "ExportedType:string:MarkerType");
            a.item("MarkerType@names", "Unset;None;Automatic;Circle;Triangle;Pyramid;Square;Diamond;Pentagon;Hexagon;Tetragram;Pentagram;Hexagram;Hidden");
            a.item("MarkerTemplateRef", "(w:MarkerTemplate,wf:MarkerTemplate)DataRef::object");
            a.item("MarkerThickness", "Number:double");
            a.item("ActualMarkerTemplateRef", "(w:ActualMarkerTemplate,wf:ActualMarkerTemplate)DataRef::object");
            a.item("MarkerBrush", "Brush");
            a.item("ActualMarkerBrush", "Brush");
            a.item("MarkerOutline", "Brush");
            a.item("ActualMarkerOutline", "Brush");
            a.item("MarkerCollisionAvoidance", "ExportedType:string:CollisionAvoidanceType");
            a.item("MarkerCollisionAvoidance@names", "None;Omit;Fade;OmitAndShift;FadeAndShift");
            a.item("MarkerOutlineMode", "ExportedType:string:MarkerOutlineMode");
            a.item("MarkerOutlineMode@names", "Auto;Normal;MatchMarkerBrush");
            a.item("MarkerFillMode", "ExportedType:string:MarkerFillMode");
            a.item("MarkerFillMode@names", "Auto;Normal;MatchMarkerOutline");
        }
        static d(a) {
            ScatterPolygonSeriesDescriptionMetadata.b(a);
            a.ae("ScatterPolygonSeries", () => new ScatterPolygonSeriesDescription());
            a.ad("ScatterPolygonSeries", ScatterPolygonSeriesDescriptionMetadata.a);
        }
    }
    ScatterPolygonSeriesDescriptionMetadata.$t = markType(ScatterPolygonSeriesDescriptionMetadata, 'ScatterPolygonSeriesDescriptionMetadata');
    ScatterPolygonSeriesDescriptionMetadata.a = null;
    return ScatterPolygonSeriesDescriptionMetadata;
})();
